// MODULE:  TextTest.java
// AUTEURS: Langlais (AWT) + Lokbani (Swing)
// OBJET: montrer TextArea, ainsi que les operations classiques sur les fichiers
//        selection d'un fichier avec FileDialog
//        lecture d'un fichier texte
//        ecriture d'un fichier texte

/*
  ralisation trs simpliste d'un diteur de fichiers
  
  non grs les tats de lecture d'criture dans un fichier.
  des composantes sont manquantes (les ascenseurs etc.)

  utilisation d'un BorderLayout
  utilisation d'un FileDialog

  Panel contient deux boutons: ouvrir et sauver
  TextArea: la zone devant contenir le contenu du fichier

 */

import java.io.*; // pour les fichiers
import java.awt.*;
import java.awt.event.*;
import javax.swing.*;

public class TextTest extends JFrame implements ActionListener {

  private JTextArea texte;
  private JButton load,save;
  private String nomFichier;

  // le constructeur
  public TextTest(int l,int h, String titre) {
     setSize(l,h);
     setTitle(titre);

     Container c = getContentPane();

     c.setLayout(new BorderLayout());

     load = new JButton("Ouvrir");
     save = new JButton("Sauver");

     load.addActionListener(this);
     save.addActionListener(this);
     save.setEnabled(false);

     JPanel p = new JPanel();
     p.add(load);
     p.add(save);

     texte = new JTextArea (10,40);


     c.add(p,BorderLayout.NORTH);
     c.add(texte,BorderLayout.SOUTH);

     show();
     setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);

  }

  // illustration de la lecture et de l'ecriture d'un fichier texte
  public void actionPerformed (ActionEvent evt) {

    if (evt.getSource() == load) { // LECTURE
      FileDialog boiteFichier = new FileDialog(this, "Ouverture de : ",FileDialog.LOAD);
      boiteFichier.show();
      nomFichier = boiteFichier.getFile();

      if (nomFichier != null) { // lecture du fichier
        try {
          BufferedReader in = new BufferedReader (new FileReader(nomFichier));
          String ligne;

          texte.setText(""); // remise a zero du texte
          while ((ligne = in.readLine()) != null)
            texte.append(ligne+"\n");
          in.close();
        }
        catch (IOException e) {
          System.err.println("Erreur de lecture avec le fichier " + nomFichier);
        }

      }

     save.setEnabled(true);
    }
  else
    if (evt.getSource() == save) {   // ECRITURE
      System.out.println("Sauvegarde de " + nomFichier);
      try {
        PrintWriter out = new PrintWriter (new FileWriter(nomFichier,true));
        out.print(texte.getText());
        out.close();
        }
      catch (IOException e) {
          System.err.println("Erreur d'ecriture avec le fichier " + nomFichier);
      }
    }
  }

  public static void main(String [] args) {
    new TextTest(330,230,"Text widget");
  }
}
